George
======

**Fast and flexible Gaussian Process regression in Python.**

.. image:: https://secure.travis-ci.org/dfm/george.svg?branch=master
        :target: http://travis-ci.org/dfm/george
.. image:: https://pypip.in/d/george/badge.svg
        :target: https://pypi.python.org/pypi/george/
.. image:: https://pypip.in/v/george/badge.svg
        :target: https://pypi.python.org/pypi/george/

Read the documentation at: `dan.iel.fm/george <http://dan.iel.fm/george>`_.
